//-----------------------------------------------------------------------
//       The GSI Online Offline Object Oriented (Go4) Project
//         Experiment Data Processing at EE department, GSI
//-----------------------------------------------------------------------
// Copyright (C) 2000- GSI Helmholtzzentrum fr Schwerionenforschung GmbH
//                     Planckstr. 1, 64291 Darmstadt, Germany
// Contact:            http://go4.gsi.de
//-----------------------------------------------------------------------
// This software can be used under the license agreements as stated
// in Go4License.txt file which is part of the distribution.
//-----------------------------------------------------------------------

#include "TXXXAnalysis.h"

#include <stdlib.h>
#include "Riostream.h"

#include "Go4EventServer.h"
#include "TGo4StepFactory.h"
#include "TGo4AnalysisStep.h"
#include "TGo4Version.h"

//***********************************************************
TXXXAnalysis::TXXXAnalysis(){}

//***********************************************************
// this constructor is called by go4analysis executable
TXXXAnalysis::TXXXAnalysis(int argc, char** argv) : TGo4Analysis(argc, argv),
  fPreLoopDone(kFALSE)
{
   cout << "**** Create TXXXAnalysis " << argv[0] << endl;

   if (!TGo4Version::CheckVersion(__GO4BUILDVERSION__)) {
      cout << "****  Go4 version mismatch" << endl;
      exit(-1);
   }

// More settings are done in macro setup.C

   gROOT->ProcessLine(".x setup.C()");
   if(argc > 1) {
     cout << "Load configuration from "<< argv[1]<<endl;
     LoadStatus(argv[1]);// config root file (as saved from GUI)
   }
   Print(); // print setup

   // Define custom passwords for analysis server
   DefineServerPasswords("XXXadmin", "XXXcontrol", "XXXview");

}

//***********************************************************
TXXXAnalysis::~TXXXAnalysis()
{
   cout << "**** TXXXAnalysis: Delete instance" << endl;
}

//-----------------------------------------------------------
Int_t TXXXAnalysis::UserPreLoop()
{
  // At this point all step objects have beeen created.
  // We check here that the necessary steps are enabled.
  // If not, we throw exception to not to start the event loop.

  Bool_t OK=kTRUE;
  TGo4AnalysisStep * step;

  if(fPreLoopDone)
      cout << "**** XXXAnalysis: UserPreLoop already done!" << endl;
  else
    {
      cout << "**** XXXAnalysis: UserPreLoop, checking step logic" << endl;
      // Physics needs input from the two calibration events:
      step = GetAnalysisStep("Physics");
      if(step->IsProcessEnabled())
	{
	  step=GetAnalysisStep("RestCal1");
	  if(!step->IsProcessEnabled())
	    {
	      cout << "**** !! XXXAnalysis: Step Physics needs step RestCal1" << endl;
	      OK=kFALSE;
	    }
	  step=GetAnalysisStep("RestCal2");
	  if(!step->IsProcessEnabled())
	    {
	      cout << "**** !! XXXAnalysis: Step Physics needs step RestCal2" << endl;
	      OK=kFALSE;
	    }
	}
      // Both Unpack steps need input from GetRaw:
      step = GetAnalysisStep("Unpack1");
      if(step->IsProcessEnabled())
	{
	  step=GetAnalysisStep("GetRaw");
	  if(!step->IsProcessEnabled())
	    {
	      cout << "**** !! XXXAnalysis: Step Unpack1 needs step GetRaw" << endl;
	      OK=kFALSE;
	    }
	}
      step = GetAnalysisStep("Unpack2");
      if(step->IsProcessEnabled())
	{
	  step=GetAnalysisStep("GetRaw");
	  if(!step->IsProcessEnabled())
	    {
	      cout << "**** !! XXXAnalysis: Step Unpack2 needs step GetRaw" << endl;
	      OK=kFALSE;
	    }
	}
    }
  fPreLoopDone=kTRUE;
  if(!OK) throw TGo4UserException(3,"XXXAnalysis: Error in step setup!");
  return 0;
}
//-----------------------------------------------------------
Int_t TXXXAnalysis::UserPostLoop()
{
  if(fPreLoopDone)
    {
      cout << "**** XXXAnalysis: UserPostLoop" << endl;
    }
  else 
      cout << "**** XXXAnalysis: UserPostLoop, no PreLoop done!" << endl;
  fPreLoopDone=kFALSE;

  return 0;
}

//-----------------------------------------------------------
Int_t TXXXAnalysis::UserEventFunc()
{
//// This function is called once for each event.
   return 0;
}
