#include "TXXXMakePhys.h"
#include "Riostream.h"
#include "TH1.h"
#include "TH2.h"

#include "TXXXEventCal1.h"
#include "TXXXEventCal2.h"
#include "TXXXEventPhys.h"

//***********************************************************
TXXXMakePhys::TXXXMakePhys() : TGo4EventProcessor("Proc")
{
  cout << "**** TXXXMakePhys: Create instance " << endl;
}
//***********************************************************
TXXXMakePhys::~TXXXMakePhys()
{
  cout << "**** TXXXMakePhys: Delete instance " << endl;
}
//***********************************************************
// this one is used in standard factory
TXXXMakePhys::TXXXMakePhys(const char* name) : TGo4EventProcessor(name)
{
  cout << "**** TXXXMakePhys: Create instance " << name << endl;

  //// init user analysis objects:

// Create of parameters and histograms (check if restored from auto save file):
  fc1x2  = (TH2I *) MakeTH2('I',"Phys/Physc1x2","Crate 1 channel 1x2",200,1,5000,200,1,5000,"Channels","Channels");
  fHis1  = (TH1I *) MakeTH1('I',"Phys/PhysHis1","Crate 1 Channel 1",1000,1,5000,"Channels");
  fHis2  = (TH1I *) MakeTH1('I',"Phys/PhysHis2","Crate 1 Channel 2",1000,1,5000,"Channels");
  fHis3  = (TH1I *) MakeTH1('I',"Phys/PhysHis3","Crate 2 Channel 1",1000,1,5000,"Channels");
  fHis4  = (TH1I *) MakeTH1('I',"Phys/PhysHis4","Crate 2 Channel 2",1000,1,5000,"Channels");
}
//-----------------------------------------------------------
// event function
Bool_t TXXXMakePhys::BuildEvent(TGo4EventElement * output)
{
  Int_t items,i;

  TXXXEventCal1 * input1  = dynamic_cast<TXXXEventCal1*> (GetInputEvent("RestCal1"));
  TXXXEventCal2 * input2  = dynamic_cast<TXXXEventCal2*> (GetInputEvent("RestCal2"));
  TXXXEventPhys * target  = dynamic_cast<TXXXEventPhys*> (output);
  items = sizeof(target->fPhys1)/sizeof(target->fPhys1[0]);
  for(i = 0; i < items; i++) target->fPhys1[i] = input1->fCal11[i];
  items = sizeof(target->fPhys2)/sizeof(target->fPhys2[0]);
  for(i = 0; i < items; i++) target->fPhys2[i] = input2->fCal22[i];

  FillHistograms(target); // fill histograms from event
  target->SetValid(kTRUE);
  return kTRUE;
}

//-----------------------------------------------------------
// histogramming function
Bool_t TXXXMakePhys::FillHistograms(TXXXEventPhys * event)
{
  Float_t c0 = (event->fPhys1[0]+event->fPhys1[1])/2;
  Float_t c1 = (event->fPhys1[2]+event->fPhys1[3])/2;
  fc1x2->Fill(c0,c1);
  fHis1->Fill(event->fPhys1[0]);                        
  fHis2->Fill(event->fPhys1[1]);                        
  fHis3->Fill(event->fPhys2[0]);                        
  fHis4->Fill(event->fPhys2[1]);                        
  return kTRUE;
}
//----------------------------END OF GO4 SOURCE FILE ---------------------
